use t::Util;
use Test::More;
use LWP::Simple;

my $service = service();
my $title = join(' - ', 'test for publish', scalar localtime);
ok my $doc = $service->add_item( 
    {
        title => $title, 
        kind => 'document',
        file => 't/data/foobar.txt',
    } 
);
is $doc->title, $title;
{
    my $rev = [ sort {$b->updated <=> $a->updated} $doc->revisions ]->[0];
    is $rev->publish, 0;
    ok $rev->publish(1);
    is $rev->publish, 1;
    ok my ($found) = grep {$_->publish == 1} $doc->revisions;
    is $found->publish, 1;
    ok my $url = $found->publish_url, "publish_url is ". $found->publish_url;
    like get($url), qr{foobar};
}
{
    my $latest = [ sort {$b->updated <=> $a->updated} $doc->revisions ]->[0];
    is $latest->publish_auto, 0;
    $latest->publish_auto(1);
}
{
    my $latest = [ sort {$b->updated <=> $a->updated} $doc->revisions ]->[0];
    is $latest->publish_auto, 1;
    is $latest->publish, 1;
}
{
    $doc->sync; # etag mismatch...
    ok $doc->update_content('t/data/hogefuga.txt'), 'update content';
    $doc->sync;
    my $latest = [ sort {$b->updated <=> $a->updated} $doc->revisions ]->[0];
    is $latest->publish_auto, 1;
    is $latest->publish, 1;
    ok my $url = $latest->publish_url, "publish_url is ". $latest->publish_url;
# I don't know why this fails. next request succeeds so no problem.
#    TODO: {
#        local $TODO = "I don't know why...";
#        ok my $res = $ua->get($url);
#        ok $res->is_success;
#        like $res->content, qr{hogefuga}, 'can get updated content via publish_url';
#    }
}
{
    my $latest = [ sort {$b->updated <=> $a->updated} $doc->revisions ]->[0];
    is $latest->publish_auto, 1;
    $latest->publish_auto(0);
    is $latest->publish_auto, 0;
    is $latest->publish, 0;
    my ($found) = grep {$_->id eq $latest->id } $doc->revisions;
    is $found->publish_auto, 0;
    is $found->publish, 0;
    ok my $published = [ grep {$_->publish == 1} $doc->revisions ]->[0];
    isnt $found->id, $published->id;
    ok my $url = $published->publish_url, "publish_url is ". $published->publish_url;
    like get($url), qr{hogefuga}, 'can get updated content via publish_url';
    $_->publish(0) for $doc->revisions;
    like get($url), qr{ServiceLogin}, 'not published any more';
}

ok $doc->delete({delete => 1});

done_testing;
